@@ -1,8 +1,10 @@
-# $Id: Recipe.pm 506 2008-06-30 17:52:14Z ykerherve $
+# $Id$
 
 package Recipe;
 use strict;
+use warnings;
 use base qw( Data::ObjectDriver::BaseObject );
+use DodTestUtil;
 
 use Data::ObjectDriver::Driver::DBI;
 
@@ -11,7 +13,7 @@ __PACKAGE__->install_properties({
     datasource => 'recipes',
     primary_key => 'recipe_id',
     driver => Data::ObjectDriver::Driver::DBI->new(
-        dsn      => 'dbi:SQLite:dbname=global.db',
+        dsn      => DodTestUtil::dsn('global'),
         reuse_dbh => 1,
     ),
 });
